# Regular cron job for the geoipupdate package, used to update GeoIP databases
#
# MaxMind typically updates their databases on Tuesdays.
#
# m h dom mon dow user  command
47 6    * * 3   root    test -x /usr/bin/geoipupdate && grep -q '^AccountID .*[^0]\+' /etc/GeoIP.conf && test ! -d /run/systemd/system && /usr/bin/geoipupdate
